local lib = LibStub:NewLibrary("MyLibrary-1.0", "$Revision: 5$")

if not lib then
  return
end

if not lib.frm then
  lib.frm = CreateFrame("Frame")
end

local function GetID(s,t)
	local id
	for k,v in pairs(t) do
		if v==s then
			id = k
		end
	end
	return id
end

local function CreateRecipeList()
	local neededRecipes = {}

	local tblData = AltoholicDB["global"]["data"]["Default"][GetRealmName()]["char"]

	for charName,charData in pairs(tblData) do
		for profName,profData in pairs(charData["recipes"]) do
			local profID = GetID(profName,LibTextbookReference["skill"])
			assert(profID,"Profession ID not found.")
			local tsRecipes = {}
			for k,v in pairs(LibTextbookDB) do
				if not v["note"] and                               --skip fake and trainable ones
				v["type"] == "RECIPE" and                          --tradeskill recipes only
				v["reqSkill"] == profID and                        --selected profession only
				v["binding"] ~= 1 and                              --skip BoP ones
				(v["quality"] > 1 or k == 10713 or k == 10644) and --skip white ones (vendored) unles they are engineer created ones
				(not v["reqClasses"] or floor(v["reqClasses"] / 2^GetID(charData["class"],LibTextbookReference["class"])) % 2 == 1) then  --see if class mask fits
					tsRecipes[v["teachesSpell"]] = k
				end
			end
			for _,str in pairs(profData["list"]) do
				local _,_,s = strsplit("^",str)
				if s then
					tsRecipes[tonumber(s)] = nil --remove if character knows the recipe
				end
			end
			for spell,item in pairs(tsRecipes) do --adding to global list
				neededRecipes[item] = neededRecipes[item] or 0 --first occurrence
				neededRecipes[item] = neededRecipes[item] + 1
			end
		end
		for _,bag in pairs(charData["bag"]) do
			for _,id in pairs(bag["ids"]) do --found in bags, subtract one
				neededRecipes[id] = neededRecipes[id] or 0 --first occurrence
				neededRecipes[id] = neededRecipes[id] - 1
			end
		end
		for _,mail in pairs(charData["mail"]) do
			local _,_,s = strsplit(":",mail["link"])
			if s then                                      --found in mail, subtract one
				local id = tonumber(s)
				neededRecipes[id] = neededRecipes[id] or 0 --first occurrence
				neededRecipes[id] = neededRecipes[id] - 1
			end
		end
	end
	
	local done = false
	while not done do --delete all existing lists
		local p = 0
		for i=1,#AUCTIONATOR_SHOPPING_LISTS do
			if AUCTIONATOR_SHOPPING_LISTS[i]["name"]=="Textbook:Recipes" then
				p = i
			end
		end
		if p > 0 then
			table.remove(AUCTIONATOR_SHOPPING_LISTS,p)
		else
			done = true
		end
	end

	local slist = Atr_SList.create("Textbook:Recipes") --make a fresh list and fill it
	for item,count in pairs(neededRecipes) do
		if count and count > 0 then
			slist:AddItem(LibTextbookDB[item]["itemName"])
		end
	end
end

lib.frm:RegisterEvent("AUCTION_HOUSE_SHOW")
lib.frm:SetScript("OnEvent", function() CreateRecipeList() end)
